@@ -1,5 +1,9 @@
 extern crate winrt_notification;
-use winrt_notification::{Duration, Sound, Toast};
+use winrt_notification::{
+    Duration,
+    Sound,
+    Toast,
+};
 
 fn main() {
     Toast::new(Toast::POWERSHELL_APP_ID)
